import useCustomTitle from './use-custom-title';
import useDynamicHeight from './use-dynamic-height';
import useFavicon from './use-favicon';
import useLocalStorage from './use-local-storage';
import useOnClickOutside from './use-on-click-outside';
import useResizeObserver from './use-resize-observer';
import useTheme from './use-theme';
import useToast from './use-toast';

export {
  useOnClickOutside,
  useDynamicHeight,
  useCustomTitle,
  useFavicon,
  useLocalStorage,
  useTheme,
  useToast,
  useResizeObserver,
};
